@@ -42,7 +42,9 @@ class ArgumentParser(Tap):
         self.add_argument(
             '-l', '--loop', help="Interval seconds. Defaults to 1.0s.")
         self.add_argument(
-            '-i', '--id', help="Target a specific GPU. If not specified, show all GPU info.")
+            '-i',
+            '--id',
+            help="Target a specific GPU. If not specified, show all GPU info.")
         self.add_argument('--config', help="Path to custom config file.")
 
 
@@ -76,13 +78,17 @@ class MyHeader(Header):  # pylint: disable=too-few-public-methods
         grid.add_column(justify="center", ratio=2)
         grid.add_column(justify="right", ratio=1)
         grid.add_row(
-            Text(f"Driver Version {self.driver_version} CUDA Version {self.cuda_version}",
-                 overflow="ellipsis"),
+            Text(
+                f"Driver Version {self.driver_version} CUDA Version {self.cuda_version}",
+                overflow="ellipsis"),
             f"[b]Rich-SMI[/] Ver. {self.version}",
             self.timestamp,
         )
 
-        return Panel(grid, border_style=self.config["border_style"], box=box.SQUARE)
+        return Panel(
+            grid,
+            border_style=self.config["border_style"],
+            box=box.SQUARE)
 
 
 class MyFooter(Footer):  # pylint: disable=too-few-public-methods
@@ -106,10 +112,12 @@ class MyFooter(Footer):  # pylint: disable=too-few-public-methods
             )
             hovered = self.highlight_key == binding.key
             key_text = Text.assemble(
-                (f" {key_display} ", "reverse" if hovered else "default on red"),
+                (f" {key_display} ",
+                 "reverse" if hovered else "default on red"),
                 f" {binding.description} ",
                 meta={
-                    "@click": f"app.press('{binding.key}')", "key": binding.key},
+                    "@click": f"app.press('{binding.key}')",
+                    "key": binding.key},
             )
             text.append_text(key_text)
 
@@ -153,7 +161,9 @@ class WidgetUtils:
         )
 
     @staticmethod
-    def create_table(headers: Iterable[str], config: dict, ratio: Optional[Iterable[int]] = None,
+    def create_table(headers: Iterable[str],
+                     config: dict,
+                     ratio: Optional[Iterable[int]] = None,
                      padding: PaddingDimensions = 0) -> Table:
         """Create rich.Table"""
 
@@ -177,8 +187,12 @@ class WidgetUtils:
             if bp_lines < BreakPoint.L:
                 table.add_column(ratio=ratio, justify="left")
             else:
-                table.add_column(header, header_style=config["table_header_style"],
-                                 ratio=ratio, justify="left", no_wrap=True)
+                table.add_column(
+                    header,
+                    header_style=config["table_header_style"],
+                    ratio=ratio,
+                    justify="left",
+                    no_wrap=True)
 
         if bp_lines < BreakPoint.L:
             table.add_row(*headers, style="bright_black", end_section=True)
@@ -237,7 +251,7 @@ class Memory(Widget):
 
         for i, memory in enumerate(memories):
             used = memory["used"]
-            total = memory["total"]
+            total = memory["total"] + 1e-6
             percent = used / total * 100.
 
             memory_bar = Progress(
@@ -305,7 +319,9 @@ class Clock(Widget):
             texts = []
             for header in headers:
                 texts.append(
-                    Text(f"{clock[header.lower()]}", style=self.config["val_normal_style"]) +
+                    (Text(f"{clock[header.lower()]}", style=self.config["val_normal_style"])
+                     if clock[header.lower()] > 0
+                     else Text("N/A", style=self.config["val_disable_style"])) +
                     Text(" MHz", style=self.config["suffix_style"])
                 )
 
@@ -355,13 +371,26 @@ class Utilization(Widget):
 
         for utilization in utilizations:
             table.add_row(
-                Text(f"{utilization['gpu']}", style=utils.get_style(
-                    utilization['gpu'], self.config)) +
-                Text(" %", style=self.config["suffix_style"]),
-                Text(f"{utilization['memory']}", style=utils.get_style(
-                    utilization['memory'], self.config)) +
-                Text(" %", style=self.config["suffix_style"])
-            )
+                (Text(
+                    f"{utilization['gpu']}",
+                    style=utils.get_style(
+                        utilization['gpu'],
+                        self.config)) if utilization['gpu'] > 0 else Text(
+                    "N/A",
+                    style=self.config["val_disable_style"])) +
+                Text(
+                    " %",
+                    style=self.config["suffix_style"]),
+                (Text(
+                    f"{utilization['memory']}",
+                    style=utils.get_style(
+                        utilization['memory'],
+                        self.config)) if utilization['memory'] > 0 else Text(
+                    "N/A",
+                    style=self.config["val_disable_style"])) +
+                Text(
+                    " %",
+                    style=self.config["suffix_style"]))
 
         return WidgetUtils.get_panel(table, self.config["utilization"],
                                      self.mouse_over)
@@ -413,20 +442,37 @@ class Power(Widget):
 
         for power in powers:
             usage = power["usage"]
-            limit = power["limit"]
+            limit = power["limit"] + 1e-6
             percent = usage / limit * 100.
 
             if bp_columns < BreakPoint.M:
                 table.add_row(
-                    Text(f"{usage:.1f}", style=utils.get_style(percent, self.config)) +
-                    Text(f"/{limit:.1f} W", style=self.config["suffix_style"]),
+                    Text(
+                        f"{usage:.1f}",
+                        style=utils.get_style(
+                            percent,
+                            self.config)) +
+                        Text(
+                        f"/{limit:.1f} W",
+                        style=self.config["suffix_style"]) if power["limit"] > 0 else Text(
+                        "N/A",
+                        style=self.config["val_disable_style"])
                 )
             else:
                 table.add_row(
-                    Text(f"{usage:.1f}", style=utils.get_style(percent, self.config)) +
-                    Text(f"/{limit:.1f} W", style=self.config["suffix_style"]),
-                    utils.render_energy_unit(power["energy"], self.config),
-                )
+                    Text(
+                        f"{usage:.1f}",
+                        style=utils.get_style(
+                            percent,
+                            self.config)) +
+                    Text(
+                        f"/{limit:.1f} W",
+                        style=self.config["suffix_style"]),
+                    utils.render_energy_unit(
+                        power["energy"],
+                        self.config) if power["limit"] > 0 else Text(
+                        "N/A",
+                        style=self.config["val_disable_style"]))
 
         return WidgetUtils.get_panel(table, self.config["power"],
                                      self.mouse_over)
@@ -487,10 +533,24 @@ class Temperature(Widget):
                 warning = "(Shut Down) "
 
             table.add_row(
-                Text(f"{board} {warning}", style=style) +
-                Text("C", style=self.config["suffix_style"]),
-                Text(f"{speed}", style=utils.get_style(speed, self.config)) +
-                Text(" %", style=self.config["suffix_style"]),
+                (Text(
+                    f"{board} {warning}",
+                    style=style) if board > 0 else Text(
+                    "N/A",
+                    style=self.config["val_disable_style"])) +
+                Text(
+                    "C",
+                    style=self.config["suffix_style"]),
+                (Text(
+                    f"{speed}",
+                    style=utils.get_style(
+                        speed,
+                        self.config)) if speed > 0 else Text(
+                            "N/A",
+                            style=self.config["val_disable_style"])) +
+                Text(
+                    " %",
+                    style=self.config["suffix_style"]),
             )
 
         return WidgetUtils.get_panel(table, self.config["temperature"],
@@ -612,7 +672,13 @@ class GraphicsProcs(Widget):
 class Body(GridView):
     """Body class"""
 
-    def __init__(self, nvml: NvmlWrapper, config: dict, loop: float, *, name: str):
+    def __init__(
+            self,
+            nvml: NvmlWrapper,
+            config: dict,
+            loop: float,
+            *,
+            name: str):
         """Constructor"""
 
         super().__init__(name=name)
@@ -671,8 +737,13 @@ class Body(GridView):
 class RichSMI(App):
     """Rich SMI"""
 
-    def __init__(self, screen: bool = True, driver_class: Optional[Any] = None,
-                 log: str = "", log_verbosity: int = 1, title: str = "Textual Application"):
+    def __init__(
+            self,
+            screen: bool = True,
+            driver_class: Optional[Any] = None,
+            log: str = "",
+            log_verbosity: int = 1,
+            title: str = "Textual Application"):
         """Constructor"""
 
         super().__init__(screen, driver_class, log, log_verbosity, title)
